local global_funcs = {}

--[=[ NOTATION
vars.key={
	format = (string), --'Int' or 'String' how to save in config file
	default = (int or string depending on format), --default setting
	key = (string), --key to write var in config file
	bool = (), -- (optional) if the value is equal to this then treat as true, otherwise false -- don't set to nil or false
} --]=]


local vars = {
	IsUseColor={ --colorize loadout names in loadout list to match ship color
		format = "Int",
		default = 1,
		key = "UseColor",
		bool = 1,
	},
	SortPresetsBy={ --sort order for loadout list
		format = "Int",
		default = 1,
		key = "SortPresetsBy",
	},
	IsCaseInsensitive={ --searches are case-insensitive
		format = "Int",
		default = 1,
		key = "CaseInsensitive",
		bool = 1,
	},
	IsPatternMatching={ --use pattern-matching in search strings
		format = "Int",
		default = 0,
		key = "PatternMatching",
		bool = 1,
	},
	IsOnlyAvailable={ --only show purchasable loadouts in loadout list
		format = "Int",
		default = 0,
		key = "ShowOnlyAvailable",
		bool = 1,
	},
	IsOnlyInventory={ --only show loadouts present in inventory in loadout list
		format = "Int",
		default = 0,
		key = "ShowOnlyInventory",
		bool = 1,
	},
	IsEnhancedPurchase={ --use enhanced purchase dialog when purchasing ships
		format = "Int",
		default = 1,
		key = "EnhancedPurchase",
		bool = 1,
	},
	IsDoubleClickBuy={ --enable purchasing loadouts by double-clicking in loadout list
		format = "Int",
		default = 0,
		key = "DoubleClickBuy",
		bool = 1,
	},
	DoubleClickDelay={ --set max double-click delay in ms, changeable from command line only
		format = "Int",
		default = 600,
		key = "DoubleClickDelay"
	},
	IsGMT={ --display timestamps in GMT for backup data
		format = "Int",
		default = 0,
		key = "IsGMT",
		bool = 1,
	},
	
	MatchShipsBy={ --options to use a loadout for a different ship
		format = "Int",
		list = {"Exact ship match only", }, --"Allow ship variants", "Ports must be compatible"},
		default = 1,
		key = "MatchShipsBy",
	},
	MatchAddonsBy={ --options for whether ships with extra or missing addons allowed
		format = "Int",
		list = {"Exact match only", }, --"Additional addons allowed", "Reconfigure to match"},
		default = 1,
		key = "MatchAddonsBy",
	},
	MatchPortsBy={ --options for whether addons allowed in different ports
		format = "Int",
		list = {"Exact match only", "Reconfigure to match", },  --"Ignore port assignments"},
		default = 1,
		key = "MatchPortsBy",
	},
	MatchWeaponGroupsBy={ --options for whether different weapon assignments allowed
		format = "Int",
		list = {"Exact match only", "Reconfigure to match", }, --"Ignore weapon groups"},
		default = 1,
		key = "MatchWeaponGroupsBy",
	},
	MatchColorsBy={ --options for how strictly to match ship color
		format = "Int",
		list = {"Exact match only", "Strict color match", "Loose color match", "Ignore ship color"},
		default = 2,
		key = "MatchColorsBy",
	},
	MatchLiveryBy={ --options for whether livery must match
		format = "Int",
		list = {"Exact match only", "Ignore livery"},
		default = 1,
		key = "MatchLiveryBy",
	},
	MatchCargoBy={ --options for whether cargo is allowed
		format = "Int",
		list = {"Exclude ships with cargo", "Unload cargo first", }, --"Cargo allowed: do not unload"}
		default = 1,
		key = "MatchCargoBy",
	},
	MatchReloadsRepairsBy={ --options for whether reloads and repairs are allowed
		format = "Int",
		list = {"Exclude ships that need reload/repairs", "Prompt to Reload & Repair", }, --"Auto Reload & Repair", "Do not reload or repair"},
		default = 1,
		key = "MatchReloadsRepairsBy",
	},
}

--// Reads specified vars from config.ini
local function read_val(key)
	local val = gkini["Read"..(vars[key].format or "String")]("SLM", vars[key].key, vars[key].default)
	if vars[key].bool then val = val == vars[key].bool end
	
	return val
end

for k,v in pairs(vars) do v.value = read_val(k) end

function global_funcs.GetVars(key)
	if vars[key] then
		vars[key].value = vars[key].value==nil and read_val(key) or vars[key].value
		return vars[key].value
	else --[[console_print'vars key not found!';]] return end
end

--// Writes specified vars value to config.ini
function global_funcs.SaveVars(key, val)
	local function save_val(key, val)
		vars[key].value = val
		
		if val==true then
			val = vars[key].bool or (vars[key].format=="Int" and 1 or 'true')
		elseif val==false then
			val = vars[key].format=="Int" and 0 or 'false'
		end
		
		gkini["Write"..(vars[key].format or "String")]("SLM", vars[key].key, val)
		
		return val
	end

	if vars[key] and val~=nil then
		return save_val(key, val)
	else return end
end

--// Gets default value for specified vars
function global_funcs.GetDefault(key) return vars[key] and vars[key].default end

--// Iterates thru list values
function global_funcs.ListIterator(key)
	if vars[key] and vars[key].list then
		return ipairs(vars[key].list)
	end
end

return global_funcs, vars